/**
 * @license
 * Copyright (c) 2016 Łukasz Kurowski <crackcomm@gmail.com>
 */
"use strict";
const program = require("commander");
const schema_1 = require("../command/schema");
const publish_1 = require("../command/publish");
const build_1 = require("../command/build");
program
    .version(require('../package.json').version)
    .option('-d, --debug', 'Debug mode');
program
    .command('build')
    .option('--ver <value>', 'Package version')
    .description('Builds TypeScript package')
    .action((cmd) => build_1.buildPackage(cmd.opts().ver)
    .catch(err => console.error(err)));
program
    .command('pack')
    .option('--ver <value>', 'Package version')
    .description('Builds TypeScript package and compresses')
    .action((cmd) => build_1.buildPackage(cmd.opts().ver)
    .then(() => build_1.packPackage())
    .catch(err => console.error(err)));
program
    .command('publish')
    .description('Builds TypeScript package and publishes')
    .option('-r, --registry <value>', 'Registry URL')
    .option('--ver <value>', 'Package version')
    .action((cmd) => build_1.buildPackage(cmd.opts().ver)
    .then(() => publish_1.publishPackage(cmd.opts().registry))
    .catch(err => console.error(err)));
program
    .command('pack-schema')
    .action(schema_1.packSchema);
if (!process.argv.slice(2).length) {
    program.outputHelp();
}
else {
    program.parse(process.argv);
}
