/**
 * @license
 * Copyright (c) 2016 Łukasz Kurowski <crackcomm@gmail.com>
 */
"use strict";
const path = require("path");
const fs = require("fs-extra-promise");
const schema_1 = require("./schema");
const escore_util_1 = require("escore-util");
/**
 * Builds TypeScript package in current working directory.
 */
function buildPackage(ver) {
    return escore_util_1.exec('tsc')
        .then(() => fs.readJSONAsync('tsconfig.json'))
        .then((config) => {
        const outDir = path.resolve(process.cwd(), config.compilerOptions.outDir);
        return escore_util_1.exec(`cp *.{md,json} ${outDir}`)
            .then(() => escore_util_1.exec(`cp -R node_modules ${outDir}`))
            .then(() => {
            const pkgPath = path.resolve(outDir, 'package.json');
            return rewritePackageVersion(pkgPath, ver);
        })
            .then(() => process.chdir(outDir))
            .then(() => {
            if (config.typhen) {
                return escore_util_1.exec('typhen')
                    .then(() => schema_1.packSchema());
            }
        });
    });
}
exports.buildPackage = buildPackage;
function packPackage() {
    return escore_util_1.exec('npm pack');
}
exports.packPackage = packPackage;
function rewritePackageVersion(file, ver) {
    return fs.readJSONAsync(file)
        .then((pkg) => {
        if (!ver && pkg.version.indexOf('PLACEHOLDER') !== -1) {
            throw new Error('Package version in --ver is required');
        }
        else {
            pkg.version = ver;
            if (pkg.peerDependencies) {
                Object.keys(pkg.peerDependencies).forEach(dep => {
                    let v = pkg.peerDependencies[dep];
                    if (v.indexOf('PLACEHOLDER') !== -1) {
                        pkg.peerDependencies[dep] = ver;
                    }
                });
            }
        }
        return pkg;
    })
        .then((pkg) => fs.writeJSONAsync(file, pkg));
}
